楚门的世界 (豆瓣)
Description: 楚门的世界电影简介和剧情介绍,楚门的世界影评、图片、预告片、影讯、论坛、在线购票
Keywords: 楚门的世界,The Truman Show,楚门的世界影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.11豆瓣电影Top250

# 楚门的世界 The Truman Show (1998)

更新描述或海报

导演: 彼得·威尔
编剧: 安德鲁·尼科尔
主演: 金·凯瑞 / 劳拉·琳妮 / 艾德·哈里斯 / 诺亚·艾默里奇 / 娜塔莎·麦克艾霍恩
类型: 剧情 / 科幻
制片国家/地区: 美国
语言: 英语
上映日期: 1998-06-05(美国)
片长: 103分钟
又名: 真人Show(港) / 真人戏 / 真人世界 / 楚门秀 / 真人秀
IMDb: tt0120382
豆瓣评分
引用
9.4
1593115人评价
5星
71.5%
4星
24.8%
3星
3.4%
2星
0.2%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
10.0
4人评价
好于 99% 剧情片
好于 99% 科幻片
我看过这部电影 2021-06-24 修改
我的评价:
推荐

## 楚门的世界的剧情简介 · · · · · ·

楚门（金•凯瑞 Jim Carrey 饰）是一个平凡得不能再平凡的人，除了一些有些稀奇的经历之外——初恋女友突然失踪、溺水身亡的父亲忽然似乎又出现在眼前，他和绝大多数30多岁的美国男人绝无异样。这令他倍感失落。他也曾试过离开自己生活了多年的地方，但总因种种理由而不能成行。
直到有一天，他忽然发觉自己似乎一直在被人跟踪，无论他走到哪里，干什么事情。这种感觉愈来愈强烈。楚门决定不惜一切代价逃离这个他生活了30多年的地方，去寻找他的初恋女友。
但他却发现自己怎样也逃不出去。真相其实很残忍。 ©豆瓣

## 楚门的世界的演职员 · · · · · · ( 全部 30 )

- 彼得·威尔 导演
- 金·凯瑞 饰 Truman Burbank
- 劳拉·琳妮 饰 Meryl Burbank / Hannah Gill
- 艾德·哈里斯 饰 Christof
- 诺亚·艾默里奇 饰 Marlon
- 娜塔莎·麦克艾霍恩 饰 Lauren / Sylvia

## 楚门的世界的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片779 · 添加 )

## 楚门的世界的获奖情况 · · · · · · ( 全部 )

- 第71届奥斯卡金像奖
- 最佳导演(提名)
- 彼得·威尔

- 第71届奥斯卡金像奖
- 最佳男配角(提名)
- 艾德·哈里斯

- 第56届金球奖
- 电影类 最佳剧情片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  盗梦空间

  黑客帝国

  星际穿越

  阿凡达

  这个男人来自地球

  E.T.外星人

  火星救援

  头号玩家

  源代码

  2001太空漫游

我要写短评

## 楚门的世界的短评 · · · · · · ( 全部 318422 条 )

热门 / 最新 / 好友

### 11935 有用 男娼起义 看过 2008-05-20 14:28:07

我是不是也在楚门的世界活着？

### 6654 有用 贾不许 看过 2008-12-08 16:31:21

Good morning, and in case I don't see ya, good afternoon, good evening, and good night!

### 102 有用 tlmgt 看过 2017-02-20 19:10:02

过誉程度堪比肖申克的救赎····

### 6775 有用 理想多钱一斤啊 看过 2009-10-07 18:46:27

原来植入广告那都是人家美国人玩剩下的玩意儿……

### 28455 有用 影志 看过 2005-12-28 01:22:04

“如果再也不能见到你，祝你早安，午安和晚安。”

> 更多短评 318422条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 CoCo陶可可 看过 2021-09-21 22:17:18

2021，021。

我要写影评

## 楚门的世界的影评 · · · · · · ( 全部 6848 条 )

热门 / 最新 / 好友
一个狗熊 2009-01-30 08:53:36

## 长大后才知道原来很多人都有过这样的恐慌

初中时候我写过一篇日记，描述了我一天的日常生活，结尾是上帝与手下的对话，大致上是说我们设计这个世界观察冉某的生活真挺有意思的。作为一个随处可见的故作深沉的初中生，我还在最后加了很装逼的话例如“我们都是上帝的羔羊”啥的。我记得当时的语文老师很好，看了我这篇日... (展开)
5513 605 816回应 收起
咻咻咻 2009-06-07 09:04:10

## 我们每个人都是楚门

被设定，被限制，被禁锢，主角在这种环境中生活了30年而不自知。 记得当初看此片时，嘴是一直张着的，太震惊了。情节太离奇了，怎么可能会有这么样的人！ 然而时隔6年再看此片，感到的却是一丝无奈和一丝悲哀。 其实我们都是楚门，差别只是，楚门最终走出了他的世界，而大多数... (展开)
6954 186 315回应 收起
伊谢尔伦的风 2008-11-05 20:13:48

## 之后的世界

楚门离开摄影棚之后做的第一件事是什么，实在再好猜不过：接受记者采访。然后参加脱口秀，出书，起诉导演和制片公司， 被反诉……最后也许有幸能隐姓埋名改头换面退隐江湖，也许会成为什么公益活动的形象大使，也许一时鬼迷心窍投身娱乐圈，就成了个终生挣扎的五流小演员，还每... (展开)
1840 195 183回应 收起
黑色镜框 2008-02-08 22:07:25

## 俄罗斯套盒、奥维尔、福柯及其他

这篇影评可能有剧透

《楚门的世界》是一个精心构造的俄罗斯套盒，其中至少包含了三层套子：最里面的当然是楚门(truman)出演的史上最大真人秀，观众是电视机前的酒吧女服务生，泡澡的糟老头……整个电影是第二层套子，观众是正在写评论的我，所有看过电影的你们；第三层套子比较隐晦：它是每个看... (展开)
1210 18 56回应 收起
CATS 2007-10-02 03:16:50

## “审判上帝”之《the TRUMAN Show》

《the TRUMAN Show》是典型的好莱坞商业片，无疑它属于娱乐电影的范畴，但透过曲折离奇，荒诞滑稽的故事情节，这部娱乐电影的主题其实十分严肃，值得玩味。 影片主要人物的个性设计是严格为阐发主题服务的。 编导从一名媒体制作人的概念延伸开去，赋予由Ed Harris饰演的Chr... (展开)
679 18 45回应 收起
陈哈 2011-07-14 15:03:03

## 我们的世界和楚门的世界

很多人第一次看了《楚门的世界》后， 都会震得半天无语。 继而，幻想我们是不是也生活在一个巨大的剧场里。 很多观众在看你生活的直播。 事实是。 楚门的世界它只是个电影。 我们，很多人和楚门的区别在于。 楚门不想表演， 他恰恰是个演员，有很多观众在看他表演。 当他发现他... (展开)
430 34 11回应 收起
solaris1972 2018-09-15 17:44:09

## 走得出桃源岛，走不出真实的荒漠

这篇影评可能有剧透

一、主题分析 “我们看戏，看厌了看厌了虚伪的表情，看厌了花巧的特技；楚门的世界，可以说是假的，楚门本人却半点不假。这节目没有剧本，没有提场，未必是杰作，但如假包换。是真实的生活。”桃源岛的设计者和总监基斯督在影片之首的独白意味深长。 法国哲学家鲍德里亚说，我... (展开)
504 8 15回应 收起
彼岸 2008-05-19 09:13:24

## 事实,究竟是不是事实呢?

这篇影评可能有剧透

常常怀疑我存在的空间. 是否的真的存在. 你是否怀疑过呢? 楚门的世界. 只有他一个人是真实的. 每天早上,和邻居打过招呼,遇到那只斑点狗, 走过旋转玻璃门去保险公司上班. 买报纸,回家有太太,和偶尔过来串门的妈妈. 生活得像一个正常人. 直到有一天,他发现自己的世界并不这般... (展开)
286 50 89回应 收起
愿此间山有木兮 2018-01-30 00:04:38

## 早安，午安，晚安

朋友的推荐让我点开了这部电影，她说楚门的世界就像你的世界。我疑惑的打开它，看完我大概理解为什么说像我的世界了。 一个住在别人编造的世界里，从小到大被别人操控着，一瞬间的怀疑但又想要随遇而安顺其自然的告诉自己，别多想。当那个生命里的人到来，她占据了你的心，她的... (展开)
249 8 16回应 收起

> 更多影评 6848篇

添加新讨论

## 讨论区 · · · · · ·

楚门的世界再刷 | 来自豆豆，逗逗变 |  | 2022-11-24 14:40:36
平淡现实却又不平凡的日子 | 来自豆友s1-_olV_QA |  | 2022-11-23 20:28:39
我们现在是不是就生活在楚门的世界里 | 来自小盒 | 5 回应 | 2022-11-23 02:19:37
细思极恐的电影 | 来自😶 | 1 回应 | 2022-11-23 02:15:40
第一次看 | 来自豆友I7lL6V7WGg |  | 2022-11-22 14:45:23

> 去这部影片的讨论区（全部892条）

## 关于《楚门的世界》的问题 · · · · · · ( 全部55个 )

- 导演最后的不舍是对楚门本人还是对自己制造的这档节目？ 22人回答
- 始终不明白一点 谁能为我解答 ？ 19人回答

> 全部55个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 咪咕视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 优酷视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 西瓜视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【容易忽视的好电影】 (影志)
- 【意外结局】 (影志)
- 【内牛满面】 (影志)
- 电影学院本科生必看100部 (志国)

## 谁在看这部电影 · · · · · ·

- 落落的暮暮
  2分钟前 想看
- 峰峰
  2分钟前 想看
- leon希尔江
  2分钟前 想看

2775947人看过 / 429661人想看

订阅楚门的世界的评论:
feed: rss 2.0